"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
const tslib_1 = require("tslib");
const fast_glob_1 = tslib_1.__importDefault(require("fast-glob"));
const fs_extra_1 = require("fs-extra");
const string_util_1 = require("@kubernetes-models/string-util");
const path_1 = require("path");
const ignore_1 = tslib_1.__importDefault(require("ignore"));
const CJS_EXT = ".js";
const ESM_EXT = ".mjs";
async function generate(args) {
    const ig = ignore_1.default();
    ig.add(args.exclude);
    if (await fs_extra_1.pathExists(args.ignoreFile)) {
        ig.add(await fs_extra_1.readFile(args.ignoreFile, "utf-8"));
    }
    const paths = await fast_glob_1.default(args.include, {
        cwd: args.cwd
    });
    paths.sort();
    const exportMap = {};
    for (const path of paths) {
        if (ig.ignores(path))
            continue;
        const base = string_util_1.trimSuffix(path, path_1.extname(path));
        const exportPath = base === "index" ? "." : `./${string_util_1.trimSuffix(base, "/index")}`;
        const requirePath = `./${base}${CJS_EXT}`;
        const importPath = `./${base}${ESM_EXT}`;
        exportMap[exportPath] = {
            require: requirePath,
            import: importPath
        };
    }
    await fs_extra_1.writeJSON(args.export, exportMap, {
        spaces: 2
    });
    console.log("Generated export map in %s", args.export);
}
exports.generate = generate;
//# sourceMappingURL=generate.js.map